# Water bills projections

In this folder, we have:

* `forecast_water_bills.py` - A script that projects water bills based on historical data and proposed increases.
* `ofwat_increases.csv` A CSV with the data from [here](https://www.ccw.org.uk/our-work/price-review/how-much-will-my-water-and-sewerage-bills-increase-by-2030/breakdown-of-water-companies-bill-increases-2025-30/) with proposed pre-inflation increases for each water company.
